@@ -5,11 +5,7 @@
 
 #include "cminpack.h"
 #include <math.h>
-#define real __cminpack_real__
-#define min(a,b) ((a) <= (b) ? (a) : (b))
-#define max(a,b) ((a) >= (b) ? (a) : (b))
-#define TRUE_ (1)
-#define FALSE_ (0)
+#include "cminpackP.h"
 
 __cminpack_attr__
 int __cminpack_func__(hybrd)(__cminpack_decl_fcn_nn__ void *p, int n, real *x, real *
@@ -250,7 +246,7 @@ int __cminpack_func__(hybrd)(__cminpack_decl_fcn_nn__ void *p, int n, real *x, r
     if (iflag < 0) {
 	goto TERMINATE;
     }
-    fnorm = __cminpack_func__(enorm)(n, &fvec[1]);
+    fnorm = __cminpack_enorm__(n, &fvec[1]);
 
 /*     determine the number of calls to fcn needed to compute */
 /*     the jacobian matrix. */
@@ -305,7 +301,7 @@ int __cminpack_func__(hybrd)(__cminpack_decl_fcn_nn__ void *p, int n, real *x, r
             for (j = 1; j <= n; ++j) {
                 wa3[j] = diag[j] * x[j];
             }
-            xnorm = __cminpack_func__(enorm)(n, &wa3[1]);
+            xnorm = __cminpack_enorm__(n, &wa3[1]);
             delta = factor * xnorm;
             if (delta == 0.) {
                 delta = factor;
@@ -389,7 +385,7 @@ int __cminpack_func__(hybrd)(__cminpack_decl_fcn_nn__ void *p, int n, real *x, r
                 wa2[j] = x[j] + wa1[j];
                 wa3[j] = diag[j] * wa1[j];
             }
-            pnorm = __cminpack_func__(enorm)(n, &wa3[1]);
+            pnorm = __cminpack_enorm__(n, &wa3[1]);
 
 /*           on the first iteration, adjust the initial step bound. */
 
@@ -404,7 +400,7 @@ int __cminpack_func__(hybrd)(__cminpack_decl_fcn_nn__ void *p, int n, real *x, r
             if (iflag < 0) {
                 goto TERMINATE;
             }
-            fnorm1 = __cminpack_func__(enorm)(n, &wa4[1]);
+            fnorm1 = __cminpack_enorm__(n, &wa4[1]);
 
 /*           compute the scaled actual reduction. */
 
@@ -426,7 +422,7 @@ int __cminpack_func__(hybrd)(__cminpack_decl_fcn_nn__ void *p, int n, real *x, r
                 }
                 wa3[i] = qtf[i] + sum;
             }
-            temp = __cminpack_func__(enorm)(n, &wa3[1]);
+            temp = __cminpack_enorm__(n, &wa3[1]);
             prered = 0.;
             if (temp < fnorm) {
                 /* Computing 2nd power */
@@ -472,7 +468,7 @@ int __cminpack_func__(hybrd)(__cminpack_decl_fcn_nn__ void *p, int n, real *x, r
                     wa2[j] = diag[j] * x[j];
                     fvec[j] = wa4[j];
                 }
-                xnorm = __cminpack_func__(enorm)(n, &wa2[1]);
+                xnorm = __cminpack_enorm__(n, &wa2[1]);
                 fnorm = fnorm1;
                 ++iter;
             }
