@@ -5,12 +5,8 @@
 
 #include "minpack.h"
 #include <math.h>
-#define real __minpack_real__
+#include "minpackP.h"
 
-#define min(a,b) ((a) <= (b) ? (a) : (b))
-#define max(a,b) ((a) >= (b) ? (a) : (b))
-#define TRUE_ (1)
-#define FALSE_ (0)
 
 __minpack_attr__
 void __minpack_func__(hybrj)(__minpack_decl_fcnder_nn__  const int *n, real *x, real *
@@ -45,7 +41,7 @@ void __minpack_func__(hybrj)(__minpack_decl_fcnder_nn__  const int *n, real *x,
     int ncsuc;
     real ratio;
     real fnorm;
-    real pnorm, xnorm, fnorm1;
+    real pnorm, xnorm = 0, fnorm1;
     int nslow1, nslow2;
     int ncfail;
     real actred, epsmch, prered;
