@@ -1,15 +1,6 @@
-/* lmstr.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
-*/
-
 #include "cminpack.h"
 #include <math.h>
-#define real __cminpack_real__
-#define min(a,b) ((a) <= (b) ? (a) : (b))
-#define max(a,b) ((a) >= (b) ? (a) : (b))
-#define TRUE_ (1)
-#define FALSE_ (0)
+#include "cminpackP.h"
 
 __cminpack_attr__
 int __cminpack_func__(lmstr)(__cminpack_decl_fcnderstr_mn__ void *p, int m, int n, real *x, 
@@ -251,7 +242,7 @@ int __cminpack_func__(lmstr)(__cminpack_decl_fcnderstr_mn__ void *p, int m, int
     if (iflag < 0) {
 	goto TERMINATE;
     }
-    fnorm = __cminpack_func__(enorm)(m, fvec);
+    fnorm = __cminpack_enorm__(m, fvec);
 
 /*     initialize levenberg-marquardt parameter and iteration counter. */
 
@@ -306,7 +297,7 @@ int __cminpack_func__(lmstr)(__cminpack_decl_fcnderstr_mn__ void *p, int m, int
                 sing = TRUE_;
             }
             ipvt[j] = j+1;
-            wa2[j] = __cminpack_func__(enorm)(j+1, &fjac[j * ldfjac + 0]);
+            wa2[j] = __cminpack_enorm__(j+1, &fjac[j * ldfjac + 0]);
         }
         if (sing) {
             __cminpack_func__(qrfac)(n, n, fjac, ldfjac, TRUE_, ipvt, n,
@@ -345,7 +336,7 @@ int __cminpack_func__(lmstr)(__cminpack_decl_fcnderstr_mn__ void *p, int m, int
             for (j = 0; j < n; ++j) {
                 wa3[j] = diag[j] * x[j];
             }
-            xnorm = __cminpack_func__(enorm)(n, wa3);
+            xnorm = __cminpack_enorm__(n, wa3);
             delta = factor * xnorm;
             if (delta == 0.) {
                 delta = factor;
@@ -405,7 +396,7 @@ int __cminpack_func__(lmstr)(__cminpack_decl_fcnderstr_mn__ void *p, int m, int
                 wa2[j] = x[j] + wa1[j];
                 wa3[j] = diag[j] * wa1[j];
             }
-            pnorm = __cminpack_func__(enorm)(n, wa3);
+            pnorm = __cminpack_enorm__(n, wa3);
 
 /*           on the first iteration, adjust the initial step bound. */
 
@@ -420,7 +411,7 @@ int __cminpack_func__(lmstr)(__cminpack_decl_fcnderstr_mn__ void *p, int m, int
             if (iflag < 0) {
                 goto TERMINATE;
             }
-            fnorm1 = __cminpack_func__(enorm)(m, wa4);
+            fnorm1 = __cminpack_enorm__(m, wa4);
 
 /*           compute the scaled actual reduction. */
 
@@ -442,7 +433,7 @@ int __cminpack_func__(lmstr)(__cminpack_decl_fcnderstr_mn__ void *p, int m, int
                     wa3[i] += fjac[i + j * ldfjac] * temp;
                 }
             }
-            temp1 = __cminpack_func__(enorm)(n, wa3) / fnorm;
+            temp1 = __cminpack_enorm__(n, wa3) / fnorm;
             temp2 = (sqrt(par) * pnorm) / fnorm;
             prered = temp1 * temp1 + temp2 * temp2 / p5;
             dirder = -(temp1 * temp1 + temp2 * temp2);
@@ -490,7 +481,7 @@ int __cminpack_func__(lmstr)(__cminpack_decl_fcnderstr_mn__ void *p, int m, int
                 for (i = 0; i < m; ++i) {
                     fvec[i] = wa4[i];
                 }
-                xnorm = __cminpack_func__(enorm)(n, wa2);
+                xnorm = __cminpack_enorm__(n, wa2);
                 fnorm = fnorm1;
                 ++iter;
             }
