@@ -5,13 +5,8 @@
 
 #include "minpack.h"
 #include <math.h>
-#define real __minpack_real__
+#include "minpackP.h"
 
-#define min(a,b) ((a) <= (b) ? (a) : (b))
-#define max(a,b) ((a) >= (b) ? (a) : (b))
-#define abs(x) ((x) >= 0 ? (x) : -(x))
-#define TRUE_ (1)
-#define FALSE_ (0)
 
 __minpack_attr__
 void __minpack_func__(lmstr)(__minpack_decl_fcnderstr_mn__ const int *m, const int *n, real *x, 
@@ -47,7 +42,7 @@ void __minpack_func__(lmstr)(__minpack_decl_fcnderstr_mn__ const int *m, const i
     int iflag;
     real delta;
     real ratio;
-    real fnorm, gnorm, pnorm, xnorm, fnorm1, actred, dirder, 
+    real fnorm, gnorm, pnorm, xnorm = 0, fnorm1, actred, dirder, 
 	    epsmch, prered;
 
 /*     ********** */
