@@ -5,9 +5,8 @@
 
 #include "minpack.h"
 #include <math.h>
-#define real __minpack_real__
+#include "minpackP.h"
 
-#define min(a,b) ((a) <= (b) ? (a) : (b))
 
 __minpack_attr__
 void __minpack_func__(qform)(const int *m, const int *n, real *q, const int *
